@@ -33,6 +33,6 @@ int ch341a_spi_send_command(unsigned int writecnt, unsigned int readcnt, const u
 int enable_pins(bool enable);
 int config_stream(unsigned int speed);
 int ch341a_init_i2c(void);
-int ch341a_init(uint8_t chipType);
+int ch341a_init(uint8_t chipType, uint8_t i2cSpeed);
 #endif /* __CH341_SPI_H__ */
 /* End of [ch341a_spi.h] package */
